Modify the set component of the memcpy test (unclear why there is a memset component to begin with).

[ROCm/hip commit: 4131b47134]
Este commit está contenido en:
Alex Voicu
2017-11-21 17:52:01 +00:00
padre d71132de7c
commit d8db534805
@@ -23,7 +23,7 @@ __global__ void cpy(hipLaunchParm lp, uint32_t *Out, uint32_t *In)
__global__ void set(hipLaunchParm lp, uint32_t *ptr, uint8_t val, size_t size)
{
int tx = threadIdx.x;
memset(ptr + tx, val, (sizeof(uint32_t)*(size/LEN)));
memset(ptr + tx, val, sizeof(uint32_t));
}
int main()